#define MOZ_SOURCE_STAMP 0dc7c28f20648d597b11b60e90be9a15687656aa
#define MOZ_SOURCE_REPO https://hg.mozilla.org/releases/mozilla-esr52
#define MOZ_SOURCE_URL https://hg.mozilla.org/releases/mozilla-esr52/rev/0dc7c28f20648d597b11b60e90be9a15687656aa
